@@ -69,11 +69,14 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 			continue
 		}
 
-		redact := strings.TrimSpace(strings.Replace(urlMatch, password, strings.Repeat("*", len(password)), -1))
+		rawURL, _ := url.Parse(urlMatch)
+		rawURL.Path = ""
+
+		redact := strings.TrimSpace(strings.Replace(rawURL.String(), password, strings.Repeat("*", len(password)), -1))
 
 		s := detectors.Result{
 			DetectorType: detectorspb.DetectorType_URI,
-			Raw:          []byte(urlMatch),
+			Raw:          []byte(rawURL.String()),
 			Redacted:     redact,
 		}
 
